# test package

## Submodules

## test.test_car module

## test.test_human module

### *class* test.test_human.TestHuman(methodName='runTest')

Bases: `TestCase`

#### test_disable_debug_state()

#### test_enable_debug_state()

#### test_get_joint_limit()

#### test_get_joint_states()

#### test_get_video_status()

#### test_get_video_stream_url()

#### test_head()

#### test_move()

#### test_stand()

#### test_start()

#### test_stop()

### *async* test.test_human.on_close(ws: WebSocketConnectionClosedException)

### *async* test.test_human.on_error(ws: WebSocketException, error: Exception)

### *async* test.test_human.on_message(ws: <module 'websocket' from '/home/fftai/.pyenv/versions/3.11.0/lib/python3.11/site-packages/websocket/_\_init_\_.py'>, message: str)

### *async* test.test_human.on_open(ws: <module 'websocket' from '/home/fftai/.pyenv/versions/3.11.0/lib/python3.11/site-packages/websocket/_\_init_\_.py'>)

## Module contents
